==> react-formbuild-component-3.4.2.tgz: package/src/field/TextArea.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, FormGroup, FormText, UncontrolledTooltip, Input
} from 'reactstrap';
import {size, inRange} from 'lodash';
import {
    styleInvalid,
    styleValid,
    small,
    noPadding,
    flexR,
    padding,
    toolTipIcon,
    smallAlt
} from '../common/styles/index';
class TextareaField extends Component {
    static propTypes = {
        id: PropTypes.string.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string,
        value: PropTypes.string.isRequired,
        // eslint-disable-next-line
        onChange: PropTypes.func.isRequired,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        helpText: PropTypes.bool,
        error: PropTypes.shape
    };

    static defaultProps = {
        label: null,
        maxLength: 250,
        minLength: 2,
        helpText: null,
        error: {
            status: null
        }
    };

    constructor(props) {
        super(props);
        this.state = {dirty: false};
    }

    static validateText(input, max = 50, min = 2) {
        return inRange(size(input), min, max + 1);
    }

    validateInput() {
        const {dirty} = this.state;
        if (!dirty) {
            return null;
        }
        const {value, maxLength, minLength} = this.props;
        return TextareaField.validateText(value, maxLength, minLength) ? 'success' : 'error';
    }

    handleChange({target}) {
        const {props} = this;
        if (props.value === target.value) {
            return;
        }
        this.setState({dirty: true});
        props.onChange({target});
    }

    render() {
        const {
            id,
            name,
            label,
            value,
            maxLength,
            minLength,
            helpText,
            error
        } = this.props;
        return (
            <FormGroup validationState={this.validateInput()}>
                <Label
                    style={{...small, ...noPadding, ...flexR,...padding}}>
                    <p
                        style={noPadding}>
                        {label+" "}
                    </p>
                    {helpText && (
                        <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+name}>
                            {String.fromCharCode(0x24D8)}
                        </p>
                    )}

                </Label>
                <Input
                    id={id}
                    name={name}
                    type="textarea"
                    componentClass="textarea"
                    value={value}
                    required
                    maxLength={maxLength}
                    minLength={minLength}
                    onChange={e => this.handleChange(e)}
                />
                <p style={error.status==='valid' ?  styleValid : styleInvalid}>
                    {error.message}
                </p>
                <FormText>{helpText}
                    {helpText && (<p>&nbsp;</p>)}
                    Quedan
                    &nbsp;
                    {maxLength - size(value)}
                    &nbsp;
                    caracter(es) disponibles.
                </FormText>
                {helpText && (
                    <UncontrolledTooltip placement="right" target={'ref'+name}>
                        {helpText}
                    </UncontrolledTooltip>
                )}
            </FormGroup>
        );
    }
}

export default TextareaField;

==> react-formbuild-component-4.0.12.tgz: package/src/field/TextArea.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, FormGroup, FormText, UncontrolledTooltip, Input
} from 'reactstrap';
import {size, inRange} from 'lodash';
import {
    styleInvalid,
    styleValid,
    small,
    noPadding,
    flexR,
    padding,
    toolTipIcon,
    smallAlt
} from '../common/styles/index';
class TextareaField extends Component {
    static propTypes = {
        id: PropTypes.string.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string,
        value: PropTypes.string.isRequired,
        // eslint-disable-next-line
        onChange: PropTypes.func.isRequired,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        helpText: PropTypes.bool,
        error: PropTypes.shape
    };

    static defaultProps = {
        label: null,
        maxLength: 250,
        minLength: 2,
        helpText: null,
        error: {
            status: null
        }
    };

    constructor(props) {
        super(props);
        this.state = {dirty: false};
    }

    static validateText(input, max = 50, min = 2) {
        return inRange(size(input), min, max + 1);
    }

    validateInput() {
        const {dirty} = this.state;
        if (!dirty) {
            return null;
        }
        const {value, maxLength, minLength} = this.props;
        if (maxLength > 0) {
            return TextareaField.validateText(value, maxLength, minLength) ? 'success' : 'error';
        }

    }

    handleChange({target}) {
        const {props} = this;
        if (props.value === target.value) {
            return;
        }
        this.setState({dirty: true});
        props.onChange({target});
    }

    render() {
        const {
            id,
            name,
            label,
            value,
            maxLength,
            minLength,
            helpText,
            error
        } = this.props;
        return (
            <FormGroup validationState={this.validateInput()}>
                <Label
                    style={{...small, ...noPadding, ...flexR,...padding}}>
                    <p
                        style={noPadding}>
                        {label+" "}
                    </p>
                    {helpText && (
                        <p style={{...noPadding, ...toolTipIcon, ...smallAlt}}  id={'ref'+name}>
                            {String.fromCharCode(0x24D8)}
                        </p>
                    )}

                </Label>
                <Input
                    id={id}
                    name={name}
                    type="textarea"
                    componentClass="textarea"
                    value={value}
                    required
                    maxLength={maxLength > 0 ? maxLength : null}
                    minLength={maxLength > 0 ? minLength : null}
                    onChange={e => this.handleChange(e)}
                />
                <p style={error.status==='valid' ?  styleValid : styleInvalid}>
                    {error.message}
                </p>
                {maxLength > 0 && (
                    <FormText>{helpText}
                        {helpText && (<p>&nbsp;</p>)}
                        Quedan
                        &nbsp;
                        {maxLength - size(value)}
                        &nbsp;
                        caracter(es) disponibles.
                    </FormText>
                )}
                {helpText && (
                    <UncontrolledTooltip placement="right" target={'ref'+name}>
                        {helpText}
                    </UncontrolledTooltip>
                )}
            </FormGroup>
        );
    }
}

export default TextareaField;
